@@ -3,86 +3,126 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2011 Insecure.Com LLC. Nmap is    *
-# * also a registered trademark of Insecure.Com LLC.  This program is free  *
-# * software; you may redistribute and/or modify it under the terms of the  *
-# * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, and version detection.                                       *
+# * The Nmap Security Scanner is (C) 1996-2017 Insecure.Com LLC ("The Nmap  *
+# * Project"). Nmap is also a registered trademark of the Nmap Project.     *
+# * This program is free software; you may redistribute and/or modify it    *
+# * under the terms of the GNU General Public License as published by the   *
+# * Free Software Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE   *
+# * CLARIFICATIONS AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your   *
+# * right to use, modify, and redistribute this software under certain      *
+# * conditions.  If you wish to embed Nmap technology into proprietary      *
+# * software, we sell alternative licenses (contact sales@nmap.com).        *
+# * Dozens of software vendors already license Nmap technology such as      *
+# * host discovery, port scanning, OS detection, version detection, and     *
+# * the Nmap Scripting Engine.                                              *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
-# * misunderstandings, we consider an application to constitute a           *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
+# * misunderstandings, we interpret that term as broadly as copyright law   *
+# * allows.  For example, we consider an application to constitute a        *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
-# * interpretation of derived works with some common examples.  Our         *
-# * interpretation applies only to Nmap--we don't speak for other people's  *
-# * GPL works.                                                              *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates as well as helping to     *
-# * fund the continued development of Nmap technology.  Please email        *
-# * sales@insecure.com for further information.                             *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, the Nmap Project grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * The Nmap Project has permission to redistribute Npcap, a packet         *
+# * capturing driver and library for the Microsoft Windows platform.        *
+# * Npcap is a separate work with it's own license rather than this Nmap    *
+# * license.  Since the Npcap license does not permit redistribution        *
+# * without special permission, our Nmap Windows binary packages which      *
+# * contain Npcap may not be redistributed without special permission.      *
+# *                                                                         *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
-# * Insecure.Org development mailing lists, it is assumed that you are      *
-# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
+# * Insecure.Org development mailing lists, or checking them into the Nmap  *
+# * source code repository, it is understood (unless you specify            *
+# * otherwise) that you are offering the Nmap Project the unlimited,        *
 # * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
-# * will always be available Open Source, but this is important because the *
-# * inability to relicense code has caused devastating problems for other   *
-# * Free Software projects (such as KDE and NASM).  We also occasionally    *
-# * relicense the code to third parties as discussed above.  If you wish to *
-# * specify special license conditions of your contributions, just say so   *
-# * when you send them.                                                     *
+# * will always be available Open Source, but this is important because     *
+# * the inability to relicense code has caused devastating problems for     *
+# * other Free Software projects (such as KDE and NASM).  We also           *
+# * occasionally relicense the code to third parties as discussed above.    *
+# * If you wish to specify special license conditions of your               *
+# * contributions, just say so when you send them.                          *
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -100,6 +140,7 @@ from zenmapGUI.higwidgets.higtables import HIGTable
 from zenmapGUI.higwidgets.higlabels import HIGEntryLabel
 from zenmapGUI.higwidgets.higbuttons import HIGButton, HIGToggleButton
 
+
 class NmapOutputProperties(HIGDialog):
     def __init__(self, nmap_output_view):
         HIGDialog.__init__(self, _("Nmap Output Properties"),
@@ -130,10 +171,14 @@ class NmapOutputProperties(HIGDialog):
         #############
         # Properties:
         self.property_names = {"details": [_("details"), "MAC Address:"],
-                               "port_list": [_("port listing title"), "PORT   STATE   SERVICE"],
-                               "open_port": [_("open port"), "22/tcp   open   ssh"],
-                               "closed_port": [_("closed port"), "70/tcp   closed   gopher"],
-                               "filtered_port": [_("filtered port"), "80/tcp   filtered   http"],
+                               "port_list": [_("port listing title"),
+                                   "PORT   STATE   SERVICE"],
+                               "open_port": [_("open port"),
+                                   "22/tcp   open   ssh"],
+                               "closed_port": [_("closed port"),
+                                   "70/tcp   closed   gopher"],
+                               "filtered_port": [_("filtered port"),
+                                   "80/tcp   filtered   http"],
                                "date": [_("date"), "2006-05-26 11:14 BRT"],
                                "hostname": [_("hostname"), "scanme.nmap.org"],
                                "ip": [_("ip"), "127.0.0.1"]}
@@ -148,18 +193,23 @@ class NmapOutputProperties(HIGDialog):
             self.property_names[p].append(gtk.gdk.Color(*settings[4]))
             self.property_names[p].append(settings[5])
 
-        # Creating properties and related widgets and attaching it to main table
+        # Creating properties and related widgets and attaching it to main
+        # table
         y1 = 0
         y2 = 1
         for p in self.property_names:
             hp = HighlightProperty(p, self.property_names[p])
-            self.highlight_main_table.attach(hp.property_name_label, 0, 1, y1, y2)
+            self.highlight_main_table.attach(
+                    hp.property_name_label, 0, 1, y1, y2)
             self.highlight_main_table.attach(hp.example_label, 1, 2, y1, y2)
             self.highlight_main_table.attach(hp.bold_tg_button, 2, 3, y1, y2)
             self.highlight_main_table.attach(hp.italic_tg_button, 3, 4, y1, y2)
-            self.highlight_main_table.attach(hp.underline_tg_button, 4, 5, y1, y2)
-            self.highlight_main_table.attach(hp.text_color_button, 5, 6, y1, y2)
-            self.highlight_main_table.attach(hp.highlight_color_button, 6, 7, y1, y2)
+            self.highlight_main_table.attach(
+                    hp.underline_tg_button, 4, 5, y1, y2)
+            self.highlight_main_table.attach(
+                    hp.text_color_button, 5, 6, y1, y2)
+            self.highlight_main_table.attach(
+                    hp.highlight_color_button, 6, 7, y1, y2)
 
             # Setting example styles and colors
             hp.update_example()
@@ -169,13 +219,13 @@ class NmapOutputProperties(HIGDialog):
             y1 += 1
             y2 += 1
 
-
         # Packing main table into main vbox
         self.highlight_main_vbox.pack_start(self.highlight_main_table)
 
         # Adding color tab
-        self.properties_notebook.append_page(self.highlight_main_vbox,
-                                             gtk.Label(_("Highlight definitions")))
+        self.properties_notebook.append_page(
+                self.highlight_main_vbox,
+                gtk.Label(_("Highlight definitions")))
 
 
 class HighlightProperty(object):
@@ -201,8 +251,10 @@ class HighlightProperty(object):
         self.bold_tg_button = HIGToggleButton("", gtk.STOCK_BOLD)
         self.italic_tg_button = HIGToggleButton("", gtk.STOCK_ITALIC)
         self.underline_tg_button = HIGToggleButton("", gtk.STOCK_UNDERLINE)
-        self.text_color_button = HIGButton(_("Text"), stock=gtk.STOCK_SELECT_COLOR)
-        self.highlight_color_button = HIGButton(_("Highlight"), stock=gtk.STOCK_SELECT_COLOR)
+        self.text_color_button = HIGButton(
+                _("Text"), stock=gtk.STOCK_SELECT_COLOR)
+        self.highlight_color_button = HIGButton(
+                _("Highlight"), stock=gtk.STOCK_SELECT_COLOR)
 
     def __connect_buttons(self):
         self.bold_tg_button.connect("toggled", self.update_example)
@@ -210,20 +262,23 @@ class HighlightProperty(object):
         self.underline_tg_button.connect("toggled", self.update_example)
 
         self.text_color_button.connect("clicked", self.text_color_dialog)
-        self.highlight_color_button.connect("clicked", self.highlight_color_dialog)
-
+        self.highlight_color_button.connect(
+                "clicked", self.highlight_color_dialog)
 
     ####################################
     # Text color dialog
 
     def text_color_dialog(self, widget):
-        color_dialog = gtk.ColorSelectionDialog("%s %s" % (self.label, _("text color")))
+        color_dialog = gtk.ColorSelectionDialog(
+                "%s %s" % (self.label, _("text color")))
         color_dialog.colorsel.set_current_color(self.text_color)
 
-        color_dialog.ok_button.connect("clicked", self.text_color_dialog_ok, color_dialog)
-        color_dialog.cancel_button.connect("clicked",
-                                           self.text_color_dialog_cancel, color_dialog)
-        color_dialog.connect("delete-event", self.text_color_dialog_close, color_dialog)
+        color_dialog.ok_button.connect(
+                "clicked", self.text_color_dialog_ok, color_dialog)
+        color_dialog.cancel_button.connect(
+                "clicked", self.text_color_dialog_cancel, color_dialog)
+        color_dialog.connect(
+                "delete-event", self.text_color_dialog_close, color_dialog)
 
         color_dialog.run()
 
@@ -238,18 +293,21 @@ class HighlightProperty(object):
     def text_color_dialog_close(self, widget, extra, color_dialog):
         color_dialog.destroy()
 
-
     #########################################
     # Highlight color dialog
     def highlight_color_dialog(self, widget):
-        color_dialog = gtk.ColorSelectionDialog("%s %s" % (self.property_name,
-                                                           _("highlight color")))
+        color_dialog = gtk.ColorSelectionDialog(
+                "%s %s" % (self.property_name, _("highlight color")))
         color_dialog.colorsel.set_current_color(self.highlight_color)
 
-        color_dialog.ok_button.connect("clicked", self.highlight_color_dialog_ok, color_dialog)
-        color_dialog.cancel_button.connect("clicked", self.highlight_color_dialog_cancel,
-                                           color_dialog)
-        color_dialog.connect("delete-event", self.highlight_color_dialog_close, color_dialog)
+        color_dialog.ok_button.connect(
+                "clicked", self.highlight_color_dialog_ok, color_dialog)
+        color_dialog.cancel_button.connect(
+                "clicked", self.highlight_color_dialog_cancel,
+                color_dialog)
+        color_dialog.connect(
+                "delete-event", self.highlight_color_dialog_close,
+                color_dialog)
 
         color_dialog.run()
 
@@ -270,8 +328,9 @@ class HighlightProperty(object):
 
         attributes = pango.AttrList()
 
-        attributes.insert(pango.AttrForeground(self.text_color.red, self.text_color.green,
-                                               self.text_color.blue, start, end))
+        attributes.insert(
+                pango.AttrForeground(self.text_color.red,
+                    self.text_color.green, self.text_color.blue, start, end))
         attributes.insert(pango.AttrBackground(self.highlight_color.red,
                                                self.highlight_color.green,
                                                self.highlight_color.blue,
@@ -281,7 +340,8 @@ class HighlightProperty(object):
         if self.bold_tg_button.get_active():
             attributes.insert(pango.AttrWeight(pango.WEIGHT_HEAVY, start, end))
         else:
-            attributes.insert(pango.AttrWeight(pango.WEIGHT_NORMAL, start, end))
+            attributes.insert(
+                    pango.AttrWeight(pango.WEIGHT_NORMAL, start, end))
 
         # Italic verification
         if self.italic_tg_button.get_active():
@@ -291,13 +351,14 @@ class HighlightProperty(object):
 
         # Underline verification
         if self.underline_tg_button.get_active():
-            attributes.insert(pango.AttrUnderline(pango.UNDERLINE_SINGLE, start, end))
+            attributes.insert(
+                    pango.AttrUnderline(pango.UNDERLINE_SINGLE, start, end))
         else:
-            attributes.insert(pango.AttrUnderline(pango.UNDERLINE_NONE, start, end))
+            attributes.insert(
+                    pango.AttrUnderline(pango.UNDERLINE_NONE, start, end))
 
         self.example_label.set_attributes(attributes)
 
-
     def show_bold(self, widget):
         self.example_label.set_markup("<>")
 
